@@ -1,24 +1,22 @@
 package Workflow::Condition::Evaluate;
 
-# $Id: Evaluate.pm 454 2009-01-12 10:04:02Z jonasbn $
+# $Id: Evaluate.pm,v 1.1 2004/10/12 05:09:48 cwinters Exp $
 
-use warnings;
 use strict;
 use base qw( Workflow::Condition );
-use Log::Log4perl qw( get_logger );
+use Log::Log4perl       qw( get_logger );
 use Safe;
 use Workflow::Exception qw( condition_error configuration_error );
-use English qw( -no_match_vars );
 
-$Workflow::Condition::Evaluate::VERSION = '1.02';
+$Workflow::Condition::Evaluate::VERSION  = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( test );
-__PACKAGE__->mk_accessors(@FIELDS);
+__PACKAGE__->mk_accessors( @FIELDS );
 
 # These get put into the safe compartment...
 $Workflow::Condition::Evaluate::context = undef;
 
-my ($log);
+my ( $log );
 
 sub _init {
     my ( $self, $params ) = @_;
@@ -26,11 +24,10 @@ sub _init {
 
     $self->test( $params->{test} );
     unless ( $self->test ) {
-        configuration_error
-            "The evaluate condition must be configured with 'test'";
+        configuration_error "The evaluate condition must be configured with 'test'";
     }
-    $log->is_info
-        && $log->info("Added evaluation condition with '$params->{test}'");
+    $log->is_info &&
+        $log->info( "Added evaluation condition with '$params->{test}'" );
 }
 
 sub evaluate {
@@ -38,28 +35,25 @@ sub evaluate {
     $log ||= get_logger();
 
     my $to_eval = $self->test;
-    $log->is_info
-        && $log->info("Evaluating '$to_eval' to see if it returns true...");
+    $log->is_info &&
+        $log->info( "Evaluating '$to_eval' to see if it returns true..." );
 
     # Assign our local stuff to package variables...
     $Workflow::Condition::Evaluate::context = $wf->context->param;
 
     # Create the Safe compartment and safely eval the test...
     my $safe = Safe->new();
-
-    ## no critic (RequireInterpolationOfMetachars)
-    $safe->share('$context');
-    my $rv = $safe->reval($to_eval);
-    if ($EVAL_ERROR) {
-        $log->error("Eval code '$to_eval' threw exception: $EVAL_ERROR");
-        condition_error
-            "Condition expressed in code threw exception: $EVAL_ERROR";
+    $safe->share( '$context' );
+    my $rv = $safe->reval( $to_eval );
+    if ( $@ ) {
+        $log->error( "Eval code '$to_eval' threw exception: $@" );
+        condition_error "Condition expressed in code threw exception: $@";
     }
 
-    $log->is_debug && $log->debug("Safe eval ran ok, returned: '$rv'");
-    unless ($rv) {
+    $log->is_debug && $log->debug( "Safe eval ran ok, returned: '$rv'" );
+    unless ( $rv ) {
         condition_error "Condition expressed by test '$to_eval' did not ",
-            "return a true value.";
+                        "return a true value.";
     }
     return $rv;
 }
@@ -72,10 +66,6 @@ __END__
 
 Workflow::Condition::Evaluate - Inline condition that evaluates perl code for truth
 
-=head1 VERSION
-
-This documentation describes version 1.02 of this package
-
 =head1 SYNOPSIS
 
  <state name="foo">
@@ -104,12 +94,12 @@ It should provide a good balance.
 
 =head1 OBJECT METHODS
 
-=head3 new( \%params )
+B<new( \%params )>
 
 One of the C<\%params> should be 'test', which contains the text to
 evaluate for truth.
 
-=head3 evaluate( $wf )
+B<evaluate( $wf )>
 
 Evaluate the text passed into the constructor: if the evaluation
 returns a true value then the condition passes; if it throws an
