@@ -1,14 +1,11 @@
 package Workflow::Config::Perl;
 
-# $Id: Perl.pm 361 2008-04-05 13:23:31Z jonasbn $
+# $Id: Perl.pm,v 1.1 2004/09/13 02:03:09 cwinters Exp $
 
 use strict;
-use base                qw( Workflow::Config );
-use Log::Log4perl       qw( get_logger );
-use Workflow::Exception qw( configuration_error );
-use Data::Dumper        qw( Dumper );
+use base qw( Workflow::Config );
 
-$Workflow::Config::Perl::VERSION = '1.03';
+$Workflow::Config::Perl::VERSION  = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -17,17 +14,12 @@ sub parse {
     $log ||= get_logger();
 
     $self->_check_config_type( $type );
-
-    if (! scalar @items) {
-        return @items;
-    }
-
-    my @config_items = Workflow::Config::_expand_refs( @items );
+    my @config_items = _expand_refs( @items );
     return () unless ( scalar @config_items );
 
     my @config = ();
     foreach my $item ( @config_items ) {
-        my ( $file_name, $method );
+        my ( $file_name );
         if ( ref $item ) {
             $method = '_translate_perl';
             $file_name = '[scalar ref]';
@@ -40,24 +32,10 @@ sub parse {
         }
         $log->is_info &&
             $log->info( "Will parse '$type' Perl config file '$file_name'" );
-        my $this_config = $self->$method( $type, $item );
-#warn "This config looks like:";
-#warn Dumper (\$this_config);
+        my $this_config = $class->$method( $type, $item );
         $log->is_info &&
             $log->info( "Parsed Perl '$file_name' ok" );
-
-	if ( exists $this_config->{'type'} ) {
-	  $log->debug( "Adding typed configuration for '$type'" );
-	  push @config, $this_config;
-	}
-        elsif ( $type eq 'persister'
-		and ref $this_config->{ $type } eq 'ARRAY' ) {
-
-	  # This special exception for persister is required because
-	  # the config design for persisters was different from the
-	  # other config types. It didn't have a top level 'persister'
-	  # element. For backward compatibility, I'm adding this
-	  # exception here.
+        if ( ref $this_config->{ $type } eq 'ARRAY' ) {
             $log->debug( "Adding multiple configurations for '$type'" );
             push @config, @{ $this_config->{ $type } };
         }
@@ -122,38 +100,17 @@ Implementation of configuration parser for serialized Perl data
 structures from files/data. See L<Workflow::Config> for C<parse()>
 description.
 
-=head1 METHODS
-
-=head2 parse
-
-This method is required implemented by L<Workflow::Config>.
-
-It takes two arguments:
-
-=over
-
-=item * a string indicating the type of configuration. For a complete list of
-types please refer to L<Workflow::Config>
-
-=item * a list of filenames containing at least a single file name
-
-=back
-
-The method returns a list of configuration parameters.
-
 =head1 SEE ALSO
 
 L<Workflow::Config>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004, 2005, 2006 Chris Winters. All rights reserved.
+Copyright (c) 2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt>, current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+Chris Winters E<lt>chris@cwinters.comE<gt>
