@@ -1,33 +1,32 @@
 package Workflow::Validator;
 
-# $Id: Validator.pm 454 2009-01-12 10:04:02Z jonasbn $
+# $Id: Validator.pm,v 1.4 2004/03/08 04:56:09 cwinters Exp $
 
-use warnings;
 use strict;
 use base qw( Workflow::Base );
-use Carp qw(croak);
 
-$Workflow::Validator::VERSION = '1.05';
+$Workflow::Validator::VERSION  = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( name class );
-__PACKAGE__->mk_accessors(@FIELDS);
+__PACKAGE__->mk_accessors( @FIELDS );
 
 sub init {
     my ( $self, $params ) = @_;
     if ( $params->{name} ) {
         $self->name( $params->{name} );
-    } else {
-        $self->name("$params->{class} (init in Action)");
+    }
+    else {
+        $self->name( "$params->{class} (init in Action)" );
     }
     $self->class( $params->{class} );
-    $self->_init($params);
+    $self->_init( $params );
 }
 
-sub _init {return}
+sub _init { return }
 
 sub validate {
-    my ($self) = @_;
-    croak "Class ", ref($self), " must implement 'validate()'!\n";
+    my ( $self ) = @_;
+    die "Class ", ref( $self ), " must implement 'validate()'!\n";
 }
 
 1;
@@ -38,10 +37,6 @@ __END__
 
 Workflow::Validator - Ensure data are valid
 
-=head1 VERSION
-
-This documentation describes version 1.05 of this package
-
 =head1 SYNOPSIS
 
  # First declare the validator...
@@ -128,16 +123,12 @@ care where it comes from.
 
 =head2 Methods
 
-=head3 init( \%params )
+B<_init( \%params )>
 
 Called when the validator is first initialized. If you do not have
 sufficient information in C<\%params> you should throw an exception.
 
-=head3 _init
-
-This is a I<dummy> method, please see L</init>.
-
-=head3 validate( $workflow, $data )
+B<validate( $workflow, $data )>
 
 Determine whether your C<$data> is true or false. If necessary you can
 get the application context information from the C<$workflow> object.
